
/**
* ファイルダイアログを開きます。
*/
function showOpenDialog(filters)
{
    var dlg = new javax.swing.JFileChooser();
    if(filters != undefined) {
    	for(var i = 0; i < filters.length; i ++) {
    		var filter = filters[i];
    		dlg.addChoosableFileFilter(filter);
    	}
    }
    var result = dlg.showOpenDialog(window.swingFrame);
    if(result != javax.swing.JFileChooser.APPROVE_OPTION) {
        return null;
    }
    return dlg.selectedFile.absolutePath;
}

/**
* ファイルダイアログを開きます。
*/
function showSaveDialog(filters, defaultExt)
{
    var dlg = new javax.swing.JFileChooser();
    if(filters != undefined) {
    	for(var i = 0; i < filters.length; i ++) {
    		var filter = filters[i];
    		dlg.addChoosableFileFilter(filter);
    	}
    }
    var result = dlg.showSaveDialog(window.swingFrame);
    if(result != javax.swing.JFileChooser.APPROVE_OPTION) {
        return null;
    }
    var path = dlg.selectedFile.absolutePath;
    if(defaultExt == undefined) {
    	return path;
    }
    
    var filename = dlg.selectedFile.name;
    if(filename.lastIndexOf(".") <= 0) {
    	path = path + "." + defaultExt;
    }
    return path;
}

/**
* 最近使ったファイルメニューを取得します。
* @return 最近使ったファイルメニュー。
*/
function getRecentFileMenuItem()
{
    return findMenuItemByName(window.menu.file, "最近使ったファイル");
}

/**
* ファイルフォーマットメニューの挿入位置を取得します。
* @return 最近使ったファイルフォーマットメニュー。
*/
function getFormatMenuItem()
{
	var index = findMenuItemIndexByName(window.menu.file, "名前を付けて保存...");
	if(index < 0) {
		return null;
	}
    return findMenuSeparator(window.menu.file, index, 1);
}

/**
* バージョン情報メニューを取得します。
* @return バージョン情報メニュー。
*/
function getVersionMenuItem()
{
    return findMenuItemByName(window.menu.help, "バージョン情報/利用規定");
}

/**
* 最近使ったファイルメニューを取得します。
* @param subMenu サブメニュー。
* @param name アイテム名。
* @return 最近使ったファイルメニュー。
*/
function findMenuItemByName(subMenu, name)
{
     var childNodes = subMenu.childNodes;
     for(var i = 0; i < childNodes.length; i ++) {
        var childNode = childNodes.item(i);
        if(childNode.text == name) {
            return childNode;
        }
    }
    return null;
}

/**
* メニューのインデックスを取得します。
* @param subMenu サブメニュー。
* @param name アイテム名。
* @return メニューのインデックス。
*/
function findMenuItemIndexByName(subMenu, name)
{
     var childNodes = subMenu.childNodes;
     for(var i = 0; i < childNodes.length; i ++) {
        var childNode = childNodes.item(i);
        if(childNode.text == name) {
            return i;
        }
    }
    return -1;
}

/**
* メニューのセパレータの位置を取得します。
* @param subMenu サブメニュー。
* @param name アイテム名。
* @param startIndex 開始インデックス。
* @param separatorIndex セパレータインデックス。
* @return メニューのセパレータの位置。
*/
function findMenuSeparator(subMenu, startIndex, separatorIndex)
{
     var childNodes = subMenu.childNodes;
     var index = 0;
     for(var i = startIndex; i < childNodes.length; i ++) {
        var childNode = childNodes.item(i);
        if(childNode.type == null) {
        	continue;
        }
        if(childNode.type.indexOf("Separator") > 0) {
        	if(index == separatorIndex) {
	            return childNode;
	        }
        	index ++;
        }
    }
    return null;
}

/**
* ファイルを開きます。
* @param file ファイル。
*/
function open(file)
{
    var sysFile = window.getFile(file);
    window.core.context.openSystemViewer(sysFile);
}

/**
* ヘルプメニューコンテナを取得します。
* @param name コンテナの名前。
*/
function getHelpMenuContainer(name)
{
	var appMenu = findMenuItemByName(window.menu, "アプリ(A)");
	if(appMenu == null) {
		appMenu = window.menu.createMenuContainer("アプリ(A)");
		window.menu.appendChild(appMenu);
	}

	var helpMenu = findMenuItemByName(appMenu, name);
	if(helpMenu == null) {
		helpMenu = window.menu.createMenuContainer(name);
		appMenu.appendChild(helpMenu);
	}
	return helpMenu;
}

/**
* ポップアップメニューコンテナを取得します。
* @param name コンテナの名前。
*/
function getPopupMenuContainer(name)
{
	var helpMenu = findMenuItemByName(window.popup, name);
	if(helpMenu == null) {
		helpMenu = window.popup.createMenuContainer(name);
		window.popup.appendChild(helpMenu);
	}
	return helpMenu;
}

