// よく使う関数をまとめたjsファイルをインポート
// ext直下ではないjsファイルはimportFileでロードし使用することができる
importFile("lib/utils.js");

customizeMenu();

/**
 * メニューをカスタマイズします。
 */
function customizeMenu() {
	var menu = window.menu;
	var file = menu.file;

	var recentMenuItem = getFormatMenuItem();
	if (recentMenuItem == null) {
		alert("メニュー構成の探索に失敗しました。");
		return;
	}
	// 階層型メニューを構築
	var container = menu.createMenuContainer("テキスト形式");
	container.icon = "jp/carabiner/tarp/desktop/icons/page_white_text.png";
	container.tooltips = "ToolTip";
	file.insertBefore(container, recentMenuItem);

	comp = menu.createMenuItem("テキストファイルをインポート", importText);
	container.appendChild(comp);

	comp = menu.createMenuItem("テキストファイルをエクスポート", exportText);
	container.appendChild(comp);

	var formatManager = window.formatManager;
	var format = formatManager.createFormat([ ".txt" ]);
	format.description = "テキストファイル";
	format.loadCallback = function(context) {
		var model = context.createModel();
		var node = Packages.jp.carabiner.treeeditor.plugin.text.TextFormatUtils
				.importText(model, context.path);
		model.rootNode = node;
	};
	format.saveCallback = function(context) {
		var model = context.model;
		Packages.jp.carabiner.treeeditor.plugin.text.TextFormatUtils
				.exportText(model.rootNode, context.path);
	};
	format.loadConfirmCallback = function(path) {
		return true;
	};
	format.saveConfirmCallback = function(path) {
		return confirm("テキスト形式で保存する場合、書式情報が失われる場合があります。\nよろしいですか？");
	};
	formatManager.appendChild(format);
}

/**
 * テキストをインポートします。
 * 
 * @param ev
 *            イベント。
 */
function importText(ev) {
	var path = showOpenDialog();
	if (path == null) {
		return;
	}

	// ext/lib/treeeditor-text.jarのメソッドを呼び出し
	var node = Packages.jp.carabiner.treeeditor.plugin.text.TextFormatUtils
			.importText(document, path);
	document.rootNode = node;
    alert("テキストファイルのインポートが完了しました: " + path);
}

/**
 * テキストをエクスポートします。
 * 
 * @param ev
 *            イベント。
 */
function exportText(ev) {
	var path = showSaveDialog();
	if (path == null) {
		return;
	}

	// ext/lib/treeeditor-text.jarのメソッドを呼び出し
	Packages.jp.carabiner.treeeditor.plugin.text.TextFormatUtils.exportText(
			document.rootNode, path);
    alert("テキストファイルのエクスポートが完了しました: " + path);
}
